using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Utils.DataBase;
using PhoenixDLL.Class;
using PhoenixDLL.Class.Managers;

namespace PhoenixDLL.GUI
{
    /// <summary>
    /// Frame to manage incomplete patients
    /// </summary>
    public partial class fr_ManageIncomplete : Form
    {
        #region Variables
        /// <summary>
        /// Sql manager
        /// </summary>
        private OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);
        #endregion

        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_ManageIncomplete()
        {
            InitializeComponent();
        }
        #endregion

        #region Event
        /// <summary>
        /// RadioButton changed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_RadioButton_CheckedChanged(object sender, EventArgs e)
        {
            dgv_Patients.DataSource = null;
            dgv_Patients.Rows.Clear();
            SqlManager.SqlQuery = "SELECT * FROM Patient WHERE ";
            if (sender == this.rb_Address)
                SqlManager.SqlQuery += "Adresse LIKE \"\";";
            else if (sender == this.rb_City)
                SqlManager.SqlQuery += "Ville LIKE \"\";";
            else if (sender == this.rb_DOB)
                SqlManager.SqlQuery += "DateNaissance <= Date() - (108*365);";
            else if (sender == this.rb_FamilyName)
                SqlManager.SqlQuery += "Nom LIKE \"\";";
            else if (sender == this.rb_Mail)
                SqlManager.SqlQuery += "Mail LIKE \"\";";
            else if (sender == this.rb_PersonalTel)
                SqlManager.SqlQuery += "Telephone_Prive LIKE \"\";";
            else if (sender == this.rb_POB)
                SqlManager.SqlQuery += "Lieu_Naissance LIKE \"\";";
            else if (sender == this.rb_Profession)
                SqlManager.SqlQuery += "Profession LIKE \"\";";
            else if (sender == this.rb_Surname)
                SqlManager.SqlQuery += "Prenom LIKE \"\";";
            else if (sender == this.rb_TelPro)
                SqlManager.SqlQuery += "Telephone_Professionel LIKE \"\";";
            else if (sender == this.rb_Zip)
                SqlManager.SqlQuery += "Telephone_Professionel LIKE \"\";";
            else if (sender == rb_Clear)
            {
                dgv_Patients.DataSource = null;
                dgv_Patients.Rows.Clear();
                return;
            }
            DataSet ds = new DataSet();
            SqlManager.ExecuteSql(ref ds);
            dgv_Patients.DataSource = ds.Tables[0];
            this.SetDataGridView();
        }
        /// <summary>
        /// Mouse click on the DataGridView
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_DGV_MouseDown(object sender, MouseEventArgs e)
        {
            DataGridView.HitTestInfo HitTestInfo = this.dgv_Patients.HitTest(e.X, e.Y);
            if (HitTestInfo.RowIndex > -1)
            {
                this.dgv_Patients.SelectedRows[0].Selected = false;
                this.dgv_Patients.Rows[HitTestInfo.RowIndex].Selected = true;
                pg_Patient.SelectedObject =
                    PatientManager.Create((int)dgv_Patients.SelectedRows[0].Cells["id_Patient"].Value);
            }
        }
        /// <summary>
        /// Aplly modifications on patient
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_Apply(object sender, EventArgs e)
        {
            PatientManager pm = (PatientManager)pg_Patient.SelectedObject;
            if (pm == null)
            {
                DialogResult dr = MessageBox.Show("Aucun patient n'est slectionn. "
                    + "Aucune modification n'aura lieu. \r\nVoulez-vous quiter?",
                    "Question", MessageBoxButtons.YesNo, MessageBoxIcon.Question);
                if (dr == DialogResult.Yes) this.Close();

            }
            else
            {
                pm.Update();
                this.Close();
            }
        }
        #endregion

        #region Methods
        /// <summary>
        /// Set the visibility of the columns of the DGV
        /// </summary>
        private void SetDataGridView()
        {
            for (int i = 0; i < dgv_Patients.Columns.Count; i++)
                dgv_Patients.Columns[i].Visible = false;

            dgv_Patients.Columns["Nom"].Visible = true;
            dgv_Patients.Columns["Nom"].HeaderText = "Nom";

            dgv_Patients.Columns["Prenom"].Visible = true;
            dgv_Patients.Columns["Prenom"].HeaderText = "Prnom";

            //dgv_Patients.Columns["Lieu_Naissance"].Visible = true;
            //dgv_Patients.Columns["Lieu_Naissance"].HeaderText = "Lieu de naissance";

            dgv_Patients.Columns["DateNaissance"].Visible = true;
            dgv_Patients.Columns["DateNaissance"].HeaderText = "Date de naissance";

            //dgv_Patients.Columns["Adresse"].Visible = true;
            //dgv_Patients.Columns["Adresse"].HeaderText = "Adresse";

            //dgv_Patients.Columns["Code_Postal"].Visible = true;
            //dgv_Patients.Columns["Code_Postal"].HeaderText = "Code postal";

            //dgv_Patients.Columns["Profession"].Visible = true;
            //dgv_Patients.Columns["Profession"].HeaderText = "Profession";

            //dgv_Patients.Columns["Ville"].Visible = true;
            //dgv_Patients.Columns["Ville"].HeaderText = "Ville";

            //dgv_Patients.Columns["Telephone_Prive"].Visible = true;
            //dgv_Patients.Columns["Telephone_Prive"].HeaderText = "Tl priv";

            //dgv_Patients.Columns["Telephone_Professionel"].Visible = true;
            //dgv_Patients.Columns["Telephone_Professionel"].HeaderText = "Tl. prof.";

            //dgv_Patients.Columns["Mail"].Visible = true;
            //dgv_Patients.Columns["Mail"].HeaderText = "Mail";
        }
        #endregion
    }
}